--[[
GridStatusPVPFlag.lua
Add grid indicator for PvP

Authors: Marco
--]]

-- Libraries
local GridRoster = Grid:GetModule("GridRoster")
local GridStatus = Grid:GetModule("GridStatus")

local GridStatusPVPFlag = GridStatus:NewModule("GridStatusPVPFlag")
GridStatusPVPFlag.menuName = "PvP flag"

-- Defaults
GridStatusPVPFlag.defaultDB = {
	pvpflag = {
		text = "PvP",
		enable = true,
		color = { r = 1.0, g = 0, b = 0, a = 1 },
		priority = 75,
		range = false,
		icon = false,
	},
}

-- Mod init
function GridStatusPVPFlag:OnInitialize()
	self.super.OnInitialize(self)
	self:RegisterStatus("pvpflag", "PvP flag")
end

-- Mod enable
function GridStatusPVPFlag:OnEnable()
	self:RegisterEvent("UNIT_FACTION", "UpdateUnit")
	for _, unitid in GridRoster:IterateRoster() do
		self:UpdateUnit("UNIT_FACTION", unitid)
	end
end

function GridStatusPVPFlag:OnDisable()
	self:Debug("OnDisable")
	self:UnregisterEvent("UNIT_FACTION")
	for guid in GridRoster:IterateRoster() do
		self.core:SendStatusLost(guid, "pvpflag")
	end
end

-- Reset
function GridStatusPVPFlag:Reset()
	self.super.Reset(self)
	self:OnDisable()
	self:OnEnable()
end

function GridStatusPVPFlag:UpdateUnit(event, unitid)
	local guid = UnitGUID(unitid)
	local settings = self.db.profile.pvpflag
	self:Debug("UpdateUnit")
	if UnitIsPVP(unitid) then
		self.core:SendStatusGained(guid, "pvpflag", settings.priority,
		                           settings.range, settings.color,
		                           settings.text, nil, nil,
		                           settings.icon)
	else
		self.core:SendStatusLost(guid, "pvpflag")
	end
end
